Méthode pour passer des paramètres avec Flask
=============================================
![category](développement)
![tag](python)
![tag](flask)

Un des grand enjeux de l'utilisation d'application web, de web service est
le passage de paramètre.

Il existe 4 grands moyens.

Nous allons prendre un exemple concret: passage de l'information **location**
dans une route Flask.

```note
chaque exemple contient un test de l'utilisation
```

Passage de paramètres dans l'URL
--------------------------------

Dans cette méthode l'url utilisée est de la forme http://127.0.0.1/search/<location>

```python
from flask import Flask, request
import json

app = Flask(__name__)
app.testing = True

#url http://127.0.0.1/search/london
@app.route('/search/<location>')
def search(location=None):
    return  json.dumps({'location':location})

with app.test_client() as c:
    rv = c.get('/search/%s' % 'london')
    print(json.loads(rv.data)['location'])

```

Passage de paramètres ajouté à l'URL
------------------------------------

Dans cette méthode l'url utilisée est de la forme http://127.0.0.1/search?location=london.

Il est possible d'ajouter plusieurs paramètres ?location=london&state=england

```python
from flask import Flask, request
import json

app = Flask(__name__)
app.testing = True

#url http://127.0.0.1/search?location=london
@app.route('/search')
def search():
    location = request.args.get('location')
    return  json.dumps({'location':location})

with app.test_client() as c:
    rv = c.post('/search', query_string=dict(location='london'))
    print(json.loads(rv.data)['location'])
```

Passage de paramètres vi le contenu de la requête web
-----------------------------------------------------

Dans cette méthode l'url utilisée est de la forme http://127.0.0.1/search.
Mais la demande contient des datas qui comporte notre filtre

Dans notre exemple le contenu est au format **json**

```python
from flask import Flask, request
import json

app = Flask(__name__)
app.testing = True

#url http://127.0.0.1/search
@app.route('/search')
def search():
    location = json.loads(request.data.decode())['location']
    return  json.dumps({'location':location})

with app.test_client() as c:
    rv = c.post('/search', data=json.dumps({'location':'london'}))
    print(json.loads(rv.data)['location'])
```

Passage de paramètres via un formulaire
---------------------------------------

On utilise dans cet exemple un formulaire web classique (balise form)

```python
from flask import Flask, request
import json

app = Flask(__name__)
app.testing = True

#url http://127.0.0.1/search
@app.route('/search')
def search():
    location = request.form['location']
    return  json.dumps({'location':location})

with app.test_client() as c:
    rv = c.post('/search', data={'location':'london'})
    print(json.loads(rv.data)['location'])```
